@@ -1,13 +1,6 @@
 #!/bin/sh
 
-if test `uname` = "Darwin"
-then
-  SHLIB_EXT='.dylib'
-else
-  SHLIB_EXT='.so'
-fi
-
-mkdir -p build && cd build
+mkdir build && cd build
 
 cmake \
   -DCMAKE_PREFIX_PATH=${PREFIX} \
@@ -19,4 +12,5 @@ cmake \
 
 make python_unity -j${CPU_COUNT}
 make install/fast
+rm -r ${PREFIX}/share/gdb
 DYLD_FALLBACK_LIBRARY_PATH=${PREFIX}/lib ctest -R pyinstallcheck --output-on-failure -j${CPU_COUNT}
